#!/usr/bin/python2.2
#
# keyboard_models.py - keyboard model list
#
# Brent Fox <bfox@redhat.com>
# Mike Fulbright <msf@redhat.com>
# Jeremy Katz <katzj@redhat.com>
#
# Copyright 2002 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

from rhpl.translate import _, N_
import rhpl.translate as translate

translate.textdomain('rhpl')

class KeyboardModels:

    def get_models(self):
        return self.modelDict

    def __init__(self):
    
        self.modelDict = {
            'be-latin1'               : [_('Belgian (be-latin1)'), 'be', 'pc105', '', ''                        ],
            'bg'                      : [_('Bulgarian'), 'bg,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            'br-abnt2'                : [_('Brazilian (ABNT2)'), 'br', 'abnt2', '', ''                          ],
            'cf'                      : [_('French Canadian'), 'ca_enhanced', 'pc105', '', ''                   ],
            'cz-us-qwertz'            : [_('Czechoslovakian (qwertz)'), 'cz,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            'cz-lat2'                 : [_('Czechoslovakian'), 'cz_qwerty', 'pc105', '', ''                     ],
            'de'                      : [_('German'), 'de', 'pc105', '', ''                                     ],
            'de-latin1'               : [_('German (latin1)'), 'de', 'pc105', '', ''                            ],
            'de-latin1-nodeadkeys'    : [_('German (latin1 w/ no deadkeys)'), 'de', 'pc105', 'nodeadkeys', ''   ],
            'dvorak'                  : [_('Dvorak'), 'dvorak', 'pc105', '', ''                                 ],
            'dk'                      : [_('Danish'), 'dk', 'pc105', '', ''                                     ],
            'dk-latin1'               : [_('Danish (latin1)'), 'dk', 'pc105', '', ''                            ],
            'es'                      : [_('Spanish'), 'es', 'pc105', '', ''                                    ],
            'et'                      : [_('Estonian'), 'ee', 'pc105', '', ''                                   ],
            'fi'                      : [_('Finnish'), 'fi', 'pc105', '', ''                                    ],
            'fi-latin1'               : [_('Finnish (latin1)'), 'fi', 'pc105', '', ''                           ],
            'fr'                      : [_('French'), 'fr', 'pc105', '', ''                                     ],
            'fr-latin0'               : [_('French (latin0)'), 'fr', 'pc105', '', ''                            ],
            'fr-latin1'               : [_('French (latin1)'), 'fr', 'pc105', '', ''                            ],
            'fr-pc'                   : [_('French (pc)'), 'fr', 'pc105', '', ''                                ],
            'fr_CH'                   : [_('Swiss French'), 'fr_CH', 'pc105', '', ''                            ],
            'fr_CH-latin1'            : [_('Swiss French (latin1)'), 'fr_CH', 'pc105', '', ''                   ],
            'gr'                      : [_('Greek'), 'el,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'    ],
            'hu'                      : [_('Hungarian'), 'hu', 'pc105', '', ''                                  ],
            'hu101'                   : [_('Hungarian (101 key)'), 'hu', 'pc105', '', ''                        ],
            'is-latin1'               : [_('Icelandic'), 'is', 'pc105', '', ''                                  ],
            'it'                      : [_('Italian'), 'it', 'pc105', '', ''                                    ],
            'it-ibm'                  : [_('Italian (IBM)'), 'it', 'pc105', '', ''                              ],
            'it2'                     : [_('Italian (it2)'), 'it', 'pc105', '', ''                              ],
            'jp106'                   : [_('Japanese'), 'jp', 'jp106', '', ''                                   ],
            'la-latin1'               : [_('Latin American'), 'la', 'pc105', '', ''                             ],
            'mk-utf'                  : [_('Macedonian'), 'mk,us', 'pc105', '','grp:shift_toggle,grp_led:scroll'],
            'no'                      : [_('Norwegian'), 'no', 'pc105', '', ''                                  ],
            'no-latin1'               : [_('Norwegian (latin1)'), 'no', 'pc105', '', ''                         ],
            'pl'                      : [_('Polish'), 'pl', 'pc105', '', ''                                     ],
            'pt-latin1'               : [_('Portuguese'), 'pt', 'pc105', '', ''                                 ],
            'ro_win'                  : [_('Romanian'), 'ro', 'pc105', '', ''                                   ],
            'ru'                      : [_('Russian'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'            ],
            'ru-cp1251'               : [_('Russian (cp1251)'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'   ],
            'ru-ms'                   : [_('Russian (Microsoft)'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            'ru1'                     : [_('Russian (ru1)'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            'ru2'                     : [_('Russian (ru2)'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            'ru_win'                  : [_('Russian (win)'), 'ru,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            'speakup'                 : [_('Speakup'), 'us', 'pc105', '', ''                                    ],
            'speakup-lt'              : [_('Speakup (laptop)'), 'us', 'pc105', '', ''                           ],
            'sv-latin1'               : [_('Swedish'), 'se', 'pc105', '', ''                                    ],
            'sg'                      : [_('Swiss German'), 'de_CH', 'pc105', '', ''                            ],
            'sg-latin1'               : [_('Swiss German (latin1)'), 'de_CH', 'pc105', '', ''                   ],
            'sk-qwerty'               : [_('Slovakian'), 'sk_qwerty', 'pc105', '', ''                           ],
            'slovene'                 : [_('Slovenian'), 'si', 'pc105', '', ''                                  ],
            'trq'                     : [_('Turkish'), 'tr', 'pc105', '', ''                                    ],
            'uk'                      : [_('United Kingdom'), 'gb', 'pc105', '', ''                             ],
            'ua'                      : [_('Ukrainian'), 'ua,us', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            'us-acentos'              : [_('U.S. International'), 'us_intl', 'pc105', '', ''                    ],
            'us'                      : [_('U.S. English'), 'us', 'pc105', '', ''                               ],
            }


def get_supported_models():
    models = KeyboardModels()
    maps = models.modelDict.keys()
    maps.sort()
    for map in maps:
        print map
